@@ -4,10 +4,12 @@ import (
 	"fmt"
 
 	"github.com/MakeNowJust/heredoc/v2"
-
 	"github.com/spf13/cobra"
+
 	gitlab "gitlab.com/gitlab-org/api/client-go"
+
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 )
 
 func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
@@ -20,6 +22,9 @@ func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
 			$ glab label delete -R owner/repo foo
 		`),
 		Args: cobra.ExactArgs(1),
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
 
