@@ -9,4 +9,6 @@ const (
 	Safe = "mcp:safe"
 	// Interactive marks commands that require an interactive TTY and should be excluded from MCP
 	Interactive = "mcp:interactive"
+	// Exclude marks commands that should never be exposed via MCP
+	Exclude = "mcp:exclude"
 )
